/* This file is part of the KDE project
 * Copyright (C) 2010 Carlos Licea <carlos@kdab.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef GLOBALS_H
#define GLOBALS_H


#include <QPointF>
#include <QSizeF>

const QPointF initialsBoxPoint = QPointF(0.0,0.0);
const QSizeF initialsBoxSize = QSizeF(20.0,20.0);
const QPointF commentBoxPoint = QPointF(22.0,0.0);
const QSizeF commentBoxSize = QSizeF(100.0,100.0);

const QSizeF wholeSize = QSizeF(120.0,100.0);


#endif
